==> sunny_fluro-1.10.1%2B1.tar.gz: example/lib/config/routes.dart <==
/*
 * fluro
 * Created by Yakka
 * https://theyakka.com
 * 
 * Copyright (c) 2019 Yakka, LLC. All rights reserved.
 * See LICENSE for distribution and usage details.
 */
import 'dart:js';

import 'package:router_example/components/home/home_component.dart';
import 'package:sunny_fluro/sunny_fluro.dart';
import 'package:sunny_fluro/sunny_fluro.dart';
import 'package:router_example/config/route_handlers.dart';

part 'routes.g.dart';

@routes()
abstract class _GeneratedRoutes {
  @route.widget(HomeComponent, uri: "/")
  dynamic get root;

  @route.function(demoFunctionHandler, returns: bool, name: "Demo")
  dynamic get demo;
}

GeneratedRoutes loadRoutes(FRouter router) {
  return GeneratedRoutes(router);
}

class Routes {
  static Routes instance;
  final FRouter router;
  static const String root = '/';
  static const String demoSimple = '/demo';
  static const String demoSimpleFixedTrans = '/demo/fixedtrans';
  static const String demoFunc = '/demo/func';
  static const String deepLink = '/message';

  final AppRoute rootRoute;
  final AppRoute demoSimpleRoute;
  final AppRoute demoSimpleFixedTransRoute;
  final AppRoute demoFuncRoute;
  final AppRoute deepLinkRoute;

  Routes(this.router)
      : rootRoute = router.define(root, handler: rootHandler),
        demoSimpleRoute = router.define(demoSimple, handler: demoRouteHandler),
        demoSimpleFixedTransRoute = router.define(demoSimpleFixedTrans,
            handler: demoRouteHandler,
            transitionType: TransitionType.inFromLeft),
        demoFuncRoute =
            router.defineCompletable(demoFunc, handler: demoFunctionHandler),
        deepLinkRoute = router.define(deepLink, handler: deepLinkHandler);
}

==> sunny_fluro-1.11.0%2B1.tar.gz: example/lib/config/routes.dart <==
/*
 * fluro
 * Created by Yakka
 * https://theyakka.com
 * 
 * Copyright (c) 2019 Yakka, LLC. All rights reserved.
 * See LICENSE for distribution and usage details.
 */

import 'package:router_example/components/home/home_component.dart';
import 'package:router_example/config/route_handlers.dart';
import 'package:sunny_fluro/sunny_fluro.dart';
import 'package:flutter/widgets.dart';

part 'routes.g.dart';

@routes()
abstract class _GeneratedRoutes {
  @route.widget(HomeComponent, uri: "/")
  dynamic get root;

  @route.function(showChooserFunc, returns: String)
  dynamic get showChooser;
}

GeneratedRoutes loadRoutes(FRouter router) {
  return GeneratedRoutes(router);
}

class Routes {
  static late Routes instance;
  final FRouter router;
  static const String root = '/';
  static const String demoSimple = '/demo';
  static const String demoSimpleFixedTrans = '/demo/fixedtrans';
  static const String demoFunc = '/demo/func';
  static const String deepLink = '/message';

  final AppRoute rootRoute;
  final AppRoute demoSimpleRoute;
  final AppRoute demoSimpleFixedTransRoute;
  final AppRoute demoFuncRoute;
  final AppRoute deepLinkRoute;

  Routes(this.router)
      : rootRoute = router.define(root, handler: rootHandler),
        demoSimpleRoute = router.define(demoSimple, handler: demoRouteHandler),
        demoSimpleFixedTransRoute =
            router.define(demoSimpleFixedTrans, handler: demoRouteHandler, transitionType: TransitionType.inFromLeft),
        demoFuncRoute = router.defineCompletable(demoFunc, handler: demoFunctionHandler),
        deepLinkRoute = router.define(deepLink, handler: deepLinkHandler) {
    loadRoutes(router);
  }
}
